#!/bin/sh
# usr/opt/wrdapp/wspro/test/test.sh -- run wspro test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop]] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          11/20/95, rsregan, modified for use with e431
#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  PROG=$TOPDIR/bin/e431
  END=8
  DIVD=========================================

#
#
  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$END}                          # by default, stop at 8
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$END ; fi
  if [ $Start -gt $END -o $Stop -gt $END ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $END"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Start -gt $END ] ; then Start=$END ; fi
    if [ $Stop -gt $END ] ; then Stop=$END ; fi
    echo "Tests $Start - $Stop will be preformed"
    echo
  fi
#
# begin test runs
#
  echo
  echo $DIVD$DIVD
  echo "Begin processing E431 test runs $Start to $Stop"
  echo
  date

  $CLEAN

  Test=$Start

  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    echo
    rm -f go
    Name=ex0$Test
    echo $DATA/$Name.dat > go
    echo $Name.out >> go
    $PROG < go

    Test=`expr $Test + 1`
  done
#
  echo
  echo
  echo $DIVD$DIVD
  echo "Completed E431 test runs $Start to $Stop"
  echo
# check output against original output in $DATA directory
  $CHECK ex0
